*************
Тур по Sage
*************

Данный раздел покажет, что доступно в Sage. Для других примеров см.
"Sage Constructions", где находятся ответы на часто задаваемые вопросы.
Также см. "Справочное руководство Sage", в котором можно найти тысячи
других примеров. С данной экскурсией можно работать интерактивно, если
запустить Sage Notebook и нажать на ссылку ``Help``.

(Если уроки просматриваются в Sage Notebook, нажмите ``shift-enter`` для
того, чтобы вычислить любую ячейку ввода. До нажатия сочетания клавиш ``shift-enter``
можно редактировать текст ввода.)

.. toctree::

   tour_assignment
   tour_help
   tour_algebra
   tour_plotting
   tour_functions
   tour_rings
   tour_linalg
   tour_polynomial
   tour_groups
   tour_numtheory
   tour_advanced
